**************************************************
Alpaca - Automated Lightweight Provenance Capture
**************************************************

Alpaca is a Python package for the capture of provenance information during the
execution of Python scripts that process data.

Alpaca provides a simple API for recording the details of the functions being
executed, the data flow, and a description of parameters used.
This is accomplished with minimal code instrumentation and user intervention.

Provenance information is structured and serialized according to a model
based on the `W3C PROV format <https://www.w3.org/TR/prov-overview/>`_.

Examples are provided for the analysis of electrophysiology data, using the
open source packages `Neo <https://neuralensemble.org/neo>`_ and
`Elephant <https://python-elephant.org>`_. See `Köhler et al. (2023) <https://doi.org/10.48550/arXiv.2311.09672>`_
for a detailed description on how to capture and interpret provenance trails generated by Alpaca.

Visit the `project page on GitHub <https://github.com/INM-6/alpaca>`_, to
report bugs and issues, or to make contributions to the source code.


Table of Contents
-----------------

.. toctree::
   :maxdepth: 1

   introduction
   install
   examples
   api
   release_notes
   acknowledgments
   authors
   citation
   open_software_licenses


.. |date| date::
.. |time| date:: %H:%M